==> python_hue_v2-1.0.0-py3-none-any.whl: python_hue_v2/hue.py <==
import time

from .room import Room
from .bridge import Bridge
from .light import Light
from .scene import Scene, ScenePost
from .grouped_light import GroupedLight
from typing import List, Union


class Hue:
    def __init__(self, ip_address: str, hue_application_key: str):
        self.bridge = Bridge(ip_address=ip_address, hue_application_key=hue_application_key)

    @property
    def lights(self) -> List[Light]:
        return [Light(self.bridge, light_data['id']) for light_data in self.bridge.get_lights()]

    @property
    def scenes(self) -> List[Scene]:
        return [Scene(self.bridge, scene_data['id']) for scene_data in self.bridge.get_scenes()]

    @property
    def grouped_lights(self) -> List[GroupedLight]:
        return [
            GroupedLight(self.bridge, grouped_light_data['id'])
            for grouped_light_data in self.bridge.get_grouped_lights()
        ]
    
    @property
    def rooms(self) -> List[Room]:
        return [Room(bridge=self.bridge, room_id_v2=room_data['id']) for room_data in self.bridge.get_rooms()]

    def create_scene(self, properties: Union[dict, ScenePost]) -> list:
        if type(properties) is dict:
            return self.bridge.create_scene(properties)
        elif isinstance(properties, ScenePost):
            return self.bridge.create_scene(properties.data_dict)
        else:
            raise TypeError("Properties must be ScenePost or dict")


if __name__ == '__main__':
    hue = Hue('ecb5fa8549cd.local', '7K-IbBzEV3wZoXkTlSh6HyLTALLFsYrxCjIcW1o9')
    scenes = hue.scenes
    for scene in scenes:
        print(scene.data_dict)
    scenes[2].recall(action='static')
    print()
    time.sleep(1)
    grouped_lights = hue.grouped_lights
    grouped_lights[0].on = False
    # hue.lights[0].on = False

==> python_hue_v2-1.0.2-py3-none-any.whl: python_hue_v2/hue.py <==
import time

from .room import Room
from .bridge import Bridge
from .light import Light
from .scene import Scene, ScenePost
from .grouped_light import GroupedLight
from typing import List, Union, Optional


class Hue:
    def __init__(self, ip_address: str, hue_application_key: Optional[str] = None):
        self.bridge = Bridge(ip_address=ip_address, hue_application_key=hue_application_key)

    @property
    def lights(self) -> List[Light]:
        return [Light(self.bridge, light_data['id']) for light_data in self.bridge.get_lights()]

    @property
    def scenes(self) -> List[Scene]:
        return [Scene(self.bridge, scene_data['id']) for scene_data in self.bridge.get_scenes()]

    @property
    def grouped_lights(self) -> List[GroupedLight]:
        return [
            GroupedLight(self.bridge, grouped_light_data['id'])
            for grouped_light_data in self.bridge.get_grouped_lights()
        ]

    @property
    def rooms(self) -> List[Room]:
        return [Room(bridge=self.bridge, room_id_v2=room_data['id']) for room_data in self.bridge.get_rooms()]

    def create_scene(self, properties: Union[dict, ScenePost]) -> list:
        if type(properties) is dict:
            return self.bridge.create_scene(properties)
        elif isinstance(properties, ScenePost):
            return self.bridge.create_scene(properties.data_dict)
        else:
            raise TypeError("Properties must be ScenePost or dict")

    def delete_scene(self, scene_id):
        self.bridge.delete_scene(scene_id=scene_id)
